#[repr(C)]pub struct Syscall {
pub ssn: u16,
pub address: *const c_void,
pub hooked: bool,
}Expand description
A struct representing a parsed system call. You are free to modify these if you wanted to do something like make a syscall to a neighbor ala hell’s gate or hall or whichever one does that. This also tells you if the syscall is hooked (Some windows APIs are by default) if you’d like to act on that in any way.
Fields
ssn: u16address: *const c_voidhooked: boolTrait Implementations